# image_processing

Description
The package image_processing is used to:
    Processing:
        - Histrogram matching
        - Structural similarity
        - Resize image
    Utils:
        - Read image
        - Save image
        - Plot image
        - Plot result
        - Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

'''bash
pip install package_name
'''

## Usage

'''python
from package_name.module1_name import file1_name
file1_name.my_function()
'''

## Author
Caio Cesar

## License
[MIT](https://choosealicense.com/licenses/mit/)